@@ -86,7 +86,7 @@ def load_library():
 
     """
     tried_paths = []
-    versions = ('', '-Q16', '-Q8', '-6.Q16')
+    versions = ('', '-6', '-Q16', '-Q8', '-6.Q16')
     options = ('', 'HDRI')
     combinations = itertools.product(versions, options)
     for suffix in (version + option for version, option in combinations):
@@ -253,6 +253,14 @@ try:
     library.MagickSetImageBackgroundColor.argtypes = [ctypes.c_void_p,
                                                       ctypes.c_void_p]
 
+    library.MagickSetImageMatte.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
+    library.MagickGetImageMatteColor.argtypes = [ctypes.c_void_p,
+                                                 ctypes.c_void_p]
+
+    library.MagickSetImageMatteColor.argtypes = [ctypes.c_void_p,
+                                                 ctypes.c_void_p]
+
     library.MagickGetImageAlphaChannel.argtypes = [ctypes.c_void_p]
     library.MagickGetImageAlphaChannel.restype = ctypes.c_size_t
 
@@ -305,6 +313,10 @@ try:
 
     library.MagickSetImageUnits.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
+    library.MagickGetImageVirtualPixelMethod.argtypes = [ctypes.c_void_p]
+
+    library.MagickSetImageVirtualPixelMethod.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
     library.MagickGetImageColorspace.argtypes = [ctypes.c_void_p]
     library.MagickGetImageColorspace.restype = ctypes.c_int
 
@@ -336,6 +348,34 @@ try:
 
     library.MagickFlopImage.argtypes = [ctypes.c_void_p]
 
+    library.MagickFrameImage.argtypes = [ctypes.c_void_p,   # wand
+                                         ctypes.c_void_p,   # matte_color
+                                         ctypes.c_size_t,   # width
+                                         ctypes.c_size_t,   # height
+                                         ctypes.c_ssize_t,  # inner_bevel
+                                         ctypes.c_ssize_t]  # outer_bevel
+
+    library.MagickFunctionImage.argtypes = [ctypes.c_void_p,  # wand
+                                            ctypes.c_int,     # MagickFunction
+                                            ctypes.c_size_t,  # number_arguments
+                                            ctypes.POINTER(ctypes.c_double)]  # arguments
+
+    library.MagickFunctionImageChannel.argtypes = [ctypes.c_void_p,  # wand
+                                                   ctypes.c_int,     # channel
+                                                   ctypes.c_int,     # MagickFunction
+                                                   ctypes.c_size_t,  # number_arguments
+                                                   ctypes.POINTER(ctypes.c_double)]  # arguments
+
+    library.MagickFxImage.argtypes = [ctypes.c_void_p,  # wand
+                                      ctypes.c_char_p]  # expression
+    library.MagickFxImage.restype = ctypes.c_void_p
+
+    library.MagickFxImageChannel.argtypes = [ctypes.c_void_p,  # wand
+                                             ctypes.c_int,     # channel
+                                             ctypes.c_char_p]  # expression
+    library.MagickFxImageChannel.restype = ctypes.c_void_p
+
+
     library.MagickResetImagePage.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 
     library.MagickSampleImage.argtypes = [ctypes.c_void_p, ctypes.c_size_t,
@@ -473,11 +513,47 @@ try:
 
     library.MagickSetImageType.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
+    library.MagickEvaluateImage.argtypes = [ctypes.c_void_p,
+                                            ctypes.c_int,
+                                            ctypes.c_double]
+
+    library.MagickLevelImage.argtypes = [ctypes.c_void_p,
+                                         ctypes.c_double,
+                                         ctypes.c_double,
+                                         ctypes.c_double]
+
+    library.MagickLevelImageChannel.argtypes = [ctypes.c_void_p,
+                                                ctypes.c_int,
+                                                ctypes.c_double,
+                                                ctypes.c_double,
+                                                ctypes.c_double]
+
     library.MagickEvaluateImageChannel.argtypes = [ctypes.c_void_p,
                                                    ctypes.c_int,
                                                    ctypes.c_int,
                                                    ctypes.c_double]
 
+    library.MagickContrastStretchImage.argtypes = [ctypes.c_void_p,  # wand
+                                                   ctypes.c_double,  # black
+                                                   ctypes.c_double]  # white
+
+    library.MagickContrastStretchImageChannel.argtypes = [ctypes.c_void_p,  # wand
+                                                          ctypes.c_int,     # channel
+                                                          ctypes.c_double,  # black
+                                                          ctypes.c_double]  # white
+
+    library.MagickGammaImage.argtypes = [ctypes.c_void_p,
+                                         ctypes.c_double]
+
+    library.MagickGammaImageChannel.argtypes = [ctypes.c_void_p,
+                                                ctypes.c_int,
+                                                ctypes.c_double]
+
+
+    library.MagickLinearStretchImage.argtypes = [ctypes.c_void_p,  # wand
+                                                 ctypes.c_double,  # black
+                                                 ctypes.c_double]  # white
+
     library.MagickCompositeImage.argtypes = [ctypes.c_void_p, ctypes.c_void_p,
                                              ctypes.c_int, ctypes.c_ssize_t,
                                              ctypes.c_ssize_t]
@@ -549,6 +625,9 @@ try:
     libmagick.DestroyExceptionInfo.argtypes = [ctypes.c_void_p]
     libmagick.DestroyExceptionInfo.restype = ctypes.c_void_p
 
+    libmagick.DestroyImage.argtypes = [ctypes.c_void_p]
+    libmagick.DestroyImage.restype = ctypes.c_void_p
+
     library.MagickGetSize.argtypes = [ctypes.c_void_p,
                                       ctypes.POINTER(ctypes.c_uint),
                                       ctypes.POINTER(ctypes.c_uint)]
@@ -790,7 +869,7 @@ try:
                                            ctypes.c_void_p] # PixelWand color
 
     library.DrawGetClipPath.argtypes = [ctypes.c_void_p]
-    library.DrawGetClipPath.restype = ctypes.c_void_p
+    library.DrawGetClipPath.restype = c_magick_char_p
 
     library.DrawGetClipRule.argtypes = [ctypes.c_void_p]
     library.DrawGetClipRule.restype = ctypes.c_uint
@@ -839,10 +918,10 @@ try:
     library.DrawGetStrokeWidth.restype = ctypes.c_double
 
     library.DrawGetFont.argtypes = [ctypes.c_void_p]
-    library.DrawGetFont.restype = ctypes.c_void_p
+    library.DrawGetFont.restype = c_magick_char_p
 
     library.DrawGetFontFamily.argtypes = [ctypes.c_void_p]
-    library.DrawGetFontFamily.restype = ctypes.c_void_p
+    library.DrawGetFontFamily.restype = c_magick_char_p
 
     library.DrawGetFontResolution.argtypes = [ctypes.c_void_p, #wand
                                ctypes.POINTER(ctypes.c_double), # x
@@ -877,7 +956,7 @@ try:
         library.DrawGetTextDirection = None
 
     library.DrawGetTextEncoding.argtypes = [ctypes.c_void_p]
-    library.DrawGetTextEncoding.restype = ctypes.c_void_p
+    library.DrawGetTextEncoding.restype = c_magick_char_p
 
     try:
         library.DrawGetTextInterlineSpacing.argtypes = [ctypes.c_void_p]
@@ -895,7 +974,7 @@ try:
                                               ctypes.c_void_p]
 
     library.DrawGetVectorGraphics.argtypes = [ctypes.c_void_p]
-    library.DrawGetVectorGraphics.restype = ctypes.c_void_p
+    library.DrawGetVectorGraphics.restype = c_magick_char_p
 
     library.DrawSetGravity.argtypes = [ctypes.c_void_p,
                                        ctypes.c_int]
@@ -911,6 +990,14 @@ try:
                                             ctypes.c_char_p]
     library.MagickAnnotateImage.restype = ctypes.c_int
 
+    library.MagickDistortImage.argtypes = [ctypes.c_void_p,  # wand
+                                           ctypes.c_int,     # method
+                                           ctypes.c_size_t,  # number_arguments
+                                           ctypes.POINTER(ctypes.c_double),  # arguments
+                                           ctypes.c_int]     # bestfit
+    library.MagickDistortImage.restype = ctypes.c_int
+
+
     library.ClearDrawingWand.argtypes = [ctypes.c_void_p]
 
     library.MagickDrawImage.argtypes = [ctypes.c_void_p,
@@ -1121,7 +1208,7 @@ try:
                                         ctypes.c_double] # height
     library.DrawPushClipPath.restype = ctypes.c_uint
     library.PopDrawingWand.argtypes = [ctypes.c_void_p]
-    library.PopDrawingWandrestype = ctypes.c_uint
+    library.PopDrawingWand.restype = ctypes.c_uint
     library.DrawPopClipPath.argtypes = [ctypes.c_void_p]
     library.DrawPopDefs.argtypes = [ctypes.c_void_p]
     library.DrawPopPattern.argtypes = [ctypes.c_void_p]
@@ -1139,11 +1226,26 @@ try:
 
     library.MagickEqualizeImage.argtypes = [ctypes.c_void_p]
 
+    library.MagickQueryConfigureOption.argtypes = [ctypes.c_char_p]
+    library.MagickQueryConfigureOption.restype = c_magick_char_p
+
+    library.MagickQueryConfigureOptions.argtypes = [ctypes.c_char_p,
+                                                    ctypes.POINTER(ctypes.c_size_t)]
+    library.MagickQueryConfigureOptions.restype = ctypes.POINTER(c_magick_char_p)
+
     library.MagickQueryFontMetrics.argtypes = [ctypes.c_void_p,
                                                ctypes.c_void_p,
                                                ctypes.c_char_p]
     library.MagickQueryFontMetrics.restype = ctypes.POINTER(ctypes.c_double)
 
+    library.MagickQueryFonts.argtypes = [ctypes.c_char_p,
+                                         ctypes.POINTER(ctypes.c_size_t)]
+    library.MagickQueryFonts.restype = ctypes.POINTER(c_magick_char_p)
+
+    library.MagickQueryFormats.argtypes = [ctypes.c_char_p,
+                                           ctypes.POINTER(ctypes.c_size_t)]
+    library.MagickQueryFormats.restype = ctypes.POINTER(c_magick_char_p)
+
     library.MagickQueryMultilineFontMetrics.argtypes = [ctypes.c_void_p,
                                                         ctypes.c_void_p,
                                                         ctypes.c_char_p]
@@ -1161,11 +1263,28 @@ try:
                                             ctypes.c_double,
                                             ctypes.c_double,
                                             ctypes.c_double]
+
+    library.MagickAppendImages.argtypes = [ctypes.c_void_p,
+                                           ctypes.c_int]
+    library.MagickAppendImages.restype = ctypes.c_void_p
+
+    library.MagickTransposeImage.argtypes = [ctypes.c_void_p]
+    library.MagickTransverseImage.argtypes = [ctypes.c_void_p]
+
+
 except AttributeError:
     raise ImportError('MagickWand shared library not found or incompatible\n'
                       'Original exception was raised in:\n' +
                       traceback.format_exc())
 
+try:
+    library.MagickAutoOrientImage.argtypes = [ctypes.c_void_p]
+except AttributeError:
+    # MagickAutoOrientImage was added in 6.8.9+, we have a fallback function
+    # so we pass silently if we cant import it
+    pass
+
+
 #: (:class:`ctypes.CDLL`) The C standard library.
 libc = None
 
